rules/dates/is_date library

Classes

IsDate
Validates that the input is a date string DateTime.parse can read.

Functions

isDate(String? v) bool
checks if the input is a valid date to parse by Dart DateTime class