IsDateMillis class

checks if the input is a valid date to parse by DateTime.fromMillisecondsSinceEpoch factory

Inheritance

Constructors

IsDateMillis({bool isUtc = false, String? error})
  • isUtc - if true the DateTime will be in UTC timezone,
  • otherwise it will be in local timezone
  • const

    Properties

    defaultMessage String
    The default message (or localization key) shown when the rule fails and no inline error or registered translator is provided.
    no setteroverride
    error String?
    Passed through the constructor to provide a custom error message. If not provided, the rule may use a localized error message.
    finalinherited
    hashCode int
    The hash code for this object.
    no setterinherited
    isUtc bool
    final
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited

    Methods

    isValid(String input) bool
    Returns a boolean indicating whether the input is valid or not. Subclasses must implement this method to define the validation logic.
    override
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited