rules/it/is_boolean library

Classes

IsBool
Validates that the input is a boolean literal — true or false.

Functions

isBool(Object? input) bool
Returns true if input is a bool, or the trimmed, case-insensitive string 'true' or 'false'.