rules/languages/is_arabic_chars library
Classes
- IsArabicChars
- Validates that the input contains only Arabic letters and whitespace.
Functions
-
isArabicChars(
String input) → bool -
Returns
trueifinputconsists of Arabic letters and whitespace.
true if input consists of Arabic letters and whitespace.