ContainsAny class

check if the value contain at lest one of String form the provided list

Inheritance

Constructors

ContainsAny(List<String> value, {bool caseSensitive = false, String? error})
const

Properties

caseSensitive bool
When true, matching is case-sensitive. Defaults to false.
final
defaultMessage String
The default message (or localization key) shown when the rule fails and no inline error or registered translator is provided.
no setteroverride
error String?
Passed through the constructor to provide a custom error message. If not provided, the rule may use a localized error message.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<String>
final

Methods

isValid(String input) bool
Returns a boolean indicating whether the input is valid or not. Subclasses must implement this method to define the validation logic.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited