rules/lists/not_contains_any library

Classes

NotContainsAny
check if the value does not contain any item from the provided list

Functions

notContainsAny(String v, List<String> list) bool
Returns true if v contains none of the entries in list.