rules/numbers/max_value library

Classes

MaxValue
Validates that the parsed numeric input is less than or equal to max.

Functions

maxValue(Object? value, num max) bool
Returns true if value parses to a number less than or equal to max.