rules/numbers/min_value library

Classes

MinValue
Validates that the parsed numeric input is greater than or equal to min.

Functions

minValue(Object? value, num min) bool
Returns true if value parses to a number greater than or equal to min.