rules/phone/is_egy_number library

Classes

IsEgyptianPhone
Validates that the input is an Egyptian mobile number (010/011/012/015 + 8 digits).

Functions

isEgyptianNumber(String str) bool
Returns true if str is a valid Egyptian mobile number.