rules/text/min_length library

Classes

MinLength
checks if the input characters length is bigger than the min field

Functions

minLength(String? input, int min) bool
Returns true if input, trimmed, is at least min characters long.